@@ -1,5 +1,5 @@
 """
-SQLObject 0.14.0
+SQLObject 0.14.1
 ----------------
 
 :author: Ian Bicking <ianb@colorstudy.com>
@@ -1321,7 +1321,7 @@ class SQLObject(object):
         for n, v in zip(name, value):
             from_python = getattr(cls, '_SO_from_python_' + n)
             if from_python:
-                v = from_python(v, sqlbuilder.SQLObjectState(cls))
+                v = from_python(v, sqlbuilder.SQLObjectState(cls, connection=connection))
             new_value.append(v)
         condition = sqlbuilder.AND(*[getattr(cls.q, n)==v for n,v in zip(name, new_value)])
         return (connection or cls._connection)._SO_selectOneAlt(
